==> qt-creator-opensource-src-4.0.0.zip: qt-creator-opensource-src-4.0.0/src/plugins/subversion/subversionsettings.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef SUBVERSIONSETTINGS_H
#define SUBVERSIONSETTINGS_H

#include <vcsbase/vcsbaseclientsettings.h>

namespace Subversion {
namespace Internal {

class SubversionSettings : public VcsBase::VcsBaseClientSettings
{
public:
    static const QLatin1String useAuthenticationKey;
    static const QLatin1String userKey;
    static const QLatin1String passwordKey;
    static const QLatin1String spaceIgnorantAnnotationKey;
    static const QLatin1String diffIgnoreWhiteSpaceKey;
    static const QLatin1String logVerboseKey;

    SubversionSettings();
    bool hasAuthentication() const;

protected:
    void readLegacySettings(const QSettings *settings);
};

} // namespace Internal
} // namespace Subversion

#endif // SUBVERSIONSETTINGS_H

==> qt-creator-opensource-src-4.10.0.zip: qt-creator-opensource-src-4.10.0/src/plugins/subversion/subversionsettings.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <vcsbase/vcsbaseclientsettings.h>

namespace Subversion {
namespace Internal {

class SubversionSettings : public VcsBase::VcsBaseClientSettings
{
public:
    static const QLatin1String useAuthenticationKey;
    static const QLatin1String userKey;
    static const QLatin1String passwordKey;
    static const QLatin1String spaceIgnorantAnnotationKey;
    static const QLatin1String diffIgnoreWhiteSpaceKey;
    static const QLatin1String logVerboseKey;

    SubversionSettings();
    bool hasAuthentication() const;

protected:
    void readLegacySettings(const QSettings *settings) override;
};

} // namespace Internal
} // namespace Subversion
